GtkWidget* create_contact_list_window( CONTACT_PTR contact );
GtkWidget* create_recd_contact_list_window( CONTACT_PTR contact );

void remove_contact_list_candidate( GtkWidget *widget, gpointer data );
void info_list_candidate( GtkWidget *widget, gpointer data );
void move_contacts_to_list( GtkWidget *widget, gpointer data );
void label_drag_data_received (GtkWidget *widget, GdkDragContext *context,
                               gint x, gint y, GtkSelectionData *data,
                               guint info, guint time);
